(ib-module-docs)=
# Interactive Brokers

`broker='ib'`


## Supported Features

| Feature | Supported? | Alternative | 
| ------- | ---------- | ----------- |
| Stop loss | No | Implement manually in strategy with limit orders |
| Take profit | No | Implement manually in strategy with stop-limit orders |



## API Reference
```{eval-rst}
.. autoclass:: autotrader.brokers.ib.broker.Broker
   :members:
   :private-members:
```
